@@ -8,7 +8,6 @@ import flask
 
 from .. import utils
 
-ImgSpec = typing.Dict[str, typing.Any]
 ImgSize = typing.Tuple[int, int]
 RenditionAttrs = typing.Dict[str, typing.Any]
 
@@ -37,7 +36,7 @@ class Image(ABC):
 
     @abstractmethod
     def _get_img_attrs(self,
-                       spec: ImgSpec,
+                       spec: utils.ArgDict,
                        style_parts: typing.List[str]) -> utils.TagAttrs:
         """ Get the img attributes for the given rendition arguments. Style parts
         should be appended to the style_parts instead.
@@ -48,17 +47,19 @@ class Image(ABC):
     def _filename(self) -> str:
         """ Get the filename of the file, for default alt text purposes """
 
-    def get_img_attrs(self, **kwargs) -> utils.TagAttrs:
+    def get_img_attrs(self, params: dict) -> utils.TagAttrs:
         """ Get an attribute list (src, style, et al) for the image.
 
         Returns: a dict of attributes e.g. {'src':'foo.jpg','srcset':'foo.jpg 1x, bar.jpg 2x']
         """
 
-        params = utils.prefix_normalize(kwargs)
+        params = utils.prefix_normalize(params)
 
         styles: typing.List[str] = []
         attrs = self._get_img_attrs(params, styles)
 
+        attrs['loading'] = params.get('image_loading', 'lazy')
+
         for key in ('img_style', 'style'):
             styles += utils.as_list(params.get(key))
 
@@ -92,9 +93,7 @@ class Image(ABC):
         Returns: an HTML fragment. """
 
         try:
-            attrs = {
-                **self.get_img_attrs(**kwargs)
-            }
+            attrs = self.get_img_attrs(kwargs)
 
             if alt_text:
                 attrs['alt'] = alt_text
